@@ -16,20 +16,20 @@ class GenTest(unittest.TestCase):
         return stdout, stderr
 
     def setUp(self):
-        cmd = 'python generateDS.py --no-dates --no-versions -f -o tests/out2sup.py -s tests/out2sub.py --super=out2sup -u gends_user_methods tests/people.xsd'
+        cmd = 'python generateDS.py --no-dates --no-versions -f -o tests/out2_sup.py -s tests/out2_sub.py --super=out2_sup -u gends_user_methods tests/people.xsd'
         stdout, stderr = self.execute(cmd, cwd='..')
         self.failUnlessEqual(len(stdout), 0)
         self.failUnlessEqual(len(stderr), 0)
 
 ##     def tearDown(self):
-##         for f in [ "out2sub.py", "out2sup.py" ]:
+##         for f in [ "out2_sub.py", "out2_sup.py" ]:
 ##             try:
 ##                 os.unlink(f)
 ##             except OSError:
 ##                 pass
 
     def test_001_compare_superclasses(self):
-        cmd = 'diff out1sup.py out2sup.py'
+        cmd = 'diff out1_sup.py out2_sup.py'
         result, err = self.execute(cmd)
         #print 'len(result):', len(result)
         # Ignore the differing lines containing the date/time.
@@ -37,7 +37,7 @@ class GenTest(unittest.TestCase):
         self.check_result(result, err, ())
 
     def test_002_compare_subclasses(self):
-        cmd = 'diff out1sub.py out2sub.py'
+        cmd = 'diff out1_sub.py out2_sub.py'
         result, err = self.execute(cmd)
         # Ignore the differing lines containing the date/time.
         #self.failUnless(len(result) < 130 and result.find('Generated') > -1)
@@ -71,6 +71,12 @@ class GenTest(unittest.TestCase):
         cmd = cmdTempl % (t_, t_, t_, t_)
         result, err = self.execute(cmd, cwd='..')
         # load the XML, and verify the proper data was loaded
+        # Run these commands::
+        #     import valueof_sub
+        #     obj = valueof_sub.parse('valueof.xml')
+        #     children = obj.get_child()
+        #     print [ (x.get_name(), x.get_valueOf_()) for x in children ]
+        #
         cmdTempl = '''python -c "import %s_sub; obj = %s_sub.parse('%s.xml'); children = obj.get_child(); print [ (x.get_name(), x.get_valueOf_()) for x in children ]"'''
         cmd = cmdTempl % (t_, t_, t_)
         result, err = self.execute(cmd)
@@ -79,10 +85,16 @@ class GenTest(unittest.TestCase):
 """)
         # Now try to create a node, make sure the value of valueOf_ is passed
         # in
-        cmdTempl = '''python -c "import %s_sub; node = %s_sub.childSub.factory(name='child1', valueOf_ = 'value1'); print (node.get_name(), node.get_valueOf_())"'''
+        # Run these commands::
+        #     import valueof_sub
+        #     node = valueof_sub.childTypeSub.factory(name='child1', valueOf_ = 'value1')
+        #     print (node.get_name(), node.get_valueOf_())
+
+        cmdTempl = '''python -c "import %s_sub; node = %s_sub.childTypeSub.factory(name='child1', valueOf_ = 'value1'); print (node.get_name(), node.get_valueOf_())"'''
         cmd = cmdTempl % (t_, t_)
         print 'cmd:', cmd
         result, err = self.execute(cmd)
+        print 'result: %s' % result
         self.failUnlessEqual(result, """\
 ('child1', 'value1')
 """)
@@ -163,10 +175,10 @@ class GenTest(unittest.TestCase):
         self.check_result(result, err, ())
 
     def test_009_literal(self):
-        import out2sup
+        import out2_sup
         save_stdout = sys.stdout
         sys.stdout = open('literal2.py', 'w')
-        out2sup.parseLiteral('people.xml')
+        out2_sup.parseLiteral('people.xml')
         sys.stdout.close()
         sys.stdout = save_stdout
         infile = open('literal1.py', 'r')
@@ -218,7 +230,7 @@ class GenTest(unittest.TestCase):
 
     def test_013_procincl(self):
         cmdTempl = ('python generateDS.py --no-dates --no-versions '
-            '--silence --member-specs=list -f ' 
+            '--silence --member-specs=list -f '
             '-o tests/%s2_sup.py -s tests/%s2_sub.py '
             '--super=%s2_sup '
             'tests/%s.xsd'
@@ -234,6 +246,61 @@ class GenTest(unittest.TestCase):
         self.check_result(result, err, ())
 
 
+    def test_014_xsi_type(self):
+        cmdTempl = 'python generateDS.py --no-dates --no-versions --member-specs=list -f -o tests/%s2_sup.py -s tests/%s2_sub.py --super=%s2_sup tests/%s.xsd'
+        t_ = 'ipo'
+        cmd = cmdTempl % (t_, t_, t_, t_, )
+        result, _ = self.execute(cmd, cwd='..')
+        cmd = 'diff %s1_sup.py %s2_sup.py' % (t_, t_, )
+        result, err = self.execute(cmd)
+        self.check_result(result, err, ('sys.stdout.write',))
+        cmd = 'diff %s1_sub.py %s2_sub.py' % (t_, t_, )
+        result, err = self.execute(cmd)
+        self.check_result(result, err, ())
+        cmdTempl = 'python tests/%s2_sup.py tests/ipo.xml > tests/%s2_out.xml'
+        cmd = cmdTempl % (t_, t_, )
+        result, _ = self.execute(cmd, cwd='..')
+        cmd = 'diff %s1_out.xml %s2_out.xml' % (t_, t_, )
+        result, err = self.execute(cmd)
+        self.check_result(result, err, ())
+
+
+    def test_015_recursive_simpletype(self):
+        cmdTempl = ('python generateDS.py --no-dates --no-versions '
+            '--silence --member-specs=list -f '
+            '-o tests/%s2_sup.py -s tests/%s2_sub.py '
+            '--super=%s2_sup '
+            'tests/%s.xsd'
+            )
+        t_ = 'recursive_simpletype'
+        cmd = cmdTempl % (t_, t_, t_, t_, )
+        result, _ = self.execute(cmd, cwd='..')
+        cmd = 'diff %s1_sup.py %s2_sup.py' % (t_, t_, )
+        result, err = self.execute(cmd)
+        self.check_result(result, err, ('sys.stdout.write',))
+        cmd = 'diff %s1_sub.py %s2_sub.py' % (t_, t_, )
+        result, err = self.execute(cmd)
+        self.check_result(result, err, ())
+
+
+    def test_016_anywildcard(self):
+        cmdTempl = ('python generateDS.py --no-dates --no-versions '
+            '--silence --member-specs=list -f '
+            '-o tests/%s2_sup.py -s tests/%s2_sub.py '
+            '--super=%s2_sup '
+            'tests/%s.xsd'
+            )
+        t_ = 'anywildcard'
+        cmd = cmdTempl % (t_, t_, t_, t_, )
+        result, _ = self.execute(cmd, cwd='..')
+        cmd = 'diff %s1_sup.py %s2_sup.py' % (t_, t_, )
+        result, err = self.execute(cmd)
+        self.check_result(result, err, ('sys.stdout.write',))
+        cmd = 'diff %s1_sub.py %s2_sub.py' % (t_, t_, )
+        result, err = self.execute(cmd)
+        self.check_result(result, err, ())
+
+
     def check_result(self, result, err, ignore_strings):
         self.failUnlessEqual(len(result), 0)
         self.failUnlessEqual(len(err), 0)
